@@ -11,8 +11,7 @@ RSpec.shared_context 'terminal session' do
 
   around do |example|
     before_sourcing.call
-    session.run_command(options.join('; '))
-    session.run_command('source zsh-autosuggestions.zsh')
+    session.run_command(['source zsh-autosuggestions.zsh', *options].join('; '))
     after_sourcing.call
     session.clear_screen
 
